.. image:: https://badge.fury.io/py/folium.png
   :target: http://badge.fury.io/py/folium
.. image:: https://api.travis-ci.org/python-visualization/folium.png?branch=master
   :target: https://travis-ci.org/python-visualization/folium
.. image:: https://badges.gitter.im/Join%20Chat.svg
   :target: https://gitter.im/python-visualization/folium?utm_source=badge&utm_medium=badge&utm_campaign=pr-badge&utm_content=badge
.. image:: https://zenodo.org/badge/18669/python-visualization/folium.svg
   :target: https://zenodo.org/badge/latestdoi/18669/python-visualization/folium

folium
======

|folium|

Python Data, Leaflet.js Maps
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

`folium` builds on the data wrangling strengths of the Python ecosystem and the
mapping strengths of the Leaflet.js library. Manipulate your data in Python, 
then visualize it in a Leaflet map via `folium`.

Installation
------------

.. code:: bash

    $ pip install folium

or

.. code:: bash

    $ conda install -c conda-forge folium

Documentation
-------------

http://python-visualization.github.io/folium/docs-v0.5.0/

The documentation for the development version can be found here:
http://python-visualization.github.io/folium/docs-master/

Note that the documentation on Read the Docs is for the deprecated version
0.2.0.

Gallery
-------

There are two galleries of Jupyter notebooks with examples, which you can see
using Jupyter's nbviewer:

http://nbviewer.jupyter.org/github/python-visualization/folium/tree/master/examples/

https://nbviewer.jupyter.org/github/python-visualization/folium_contrib/tree/master/notebooks/


.. |folium| image:: http://python-visualization.github.io/folium/docs-master/_images/folium_logo.jpg
